decimalHighLow figures out the highest and lowest decimal year based on water year. The input is a data frame with columns Month and DecYear.
header_tag.html
Skip to contentsdecimalHighLow figures out the highest and lowest decimal year based on water year. The input is a data frame with columns Month and DecYear.