header_tag.html

Skip to contents

Generates a lag one auto-regressive time series, where the first and last values are fixed. Marginal expected value is zero and variance is one. Generated values have a normal conditional distribution. This version replaces genmissing and is much faster for long sample gaps.

Usage

genmissing(X1, XN, rho, N, Lfull)

Arguments

X1

value before the gap

XN

value after the gap

rho

the lag one autocorrelation

N

the length of the sequence including X1 and XN. It is two more than the gap length

Lfull

Cholesky factor created with precompute_L

Value

numeric vector of length N, conditioned on the first value (X1) and last value (XN) with the specified lag one autocorrelation in the limit (where N is large) the values are normal with mean 0 and variance 1