Sets up tick marks for an axis for a graph with an arithmetic scale which starts at zero
Source:R/yPretty.R
yPretty.RdAxis tick marks that run from zero to some specified maximum, creates about 4 to 8 ticks marks.
header_tag.html
Skip to contents
R/yPretty.R
yPretty.RdAxis tick marks that run from zero to some specified maximum, creates about 4 to 8 ticks marks.