Generates a lag one auto-regressive time series, where the first and last values are fixed. Marginal expected value is zero and variance is one. Generated values have a normal conditional distribution.
header_tag.html
Skip to contentsGenerates a lag one auto-regressive time series, where the first and last values are fixed. Marginal expected value is zero and variance is one. Generated values have a normal conditional distribution.