Learn R Programming

EGRET (version 3.0.12)

tableResults: Table of annual results for discharge, concentration and flux

Description

Produce an ASCII table showing: year, mean discharge, mean concentration, flow-normalized concentration, mean flux, and flow-normalized flux. Note that the flux and flow-normalized flux are rates and not a mass. As such a value for some period shorter than a full year could be larger than the value for a full year.

Usage

tableResults(eList, qUnit = 2, fluxUnit = 9, localDaily = NA)

Value

dataframe with columns year, mean discharge, mean concentration, mean flow-normalized concentration, mean Kalman concentration (if it has been calculated), mean flux, mean flow-normalized flux, and mean Kalman flux (if it has been calculated).

Arguments

eList

named list with at least Daily and INFO dataframes

qUnit

object of qUnit class. printqUnitCheatSheet, or numeric represented the short code, or character representing the descriptive name.

fluxUnit

object of fluxUnit class. printFluxUnitCheatSheet, or numeric represented the short code, or character representing the descriptive name.

localDaily

data frame to override eList$Daily

Details

Can also procude a table for any Period of Analysis (individual months or sequence of months) using setPA.

Examples

Run this code
eList <- Choptank_eList
# Water Year:
# \donttest{
tableResults(eList, fluxUnit = 8)
df <- tableResults(eList, fluxUnit = 1)
df
# Spring:
eList <- setPA(eList, paStart = 3, paLong = 3)
tableResults(eList, fluxUnit = 1, qUnit = "cfs")
# }

Run the code above in your browser using DataLab